from django.db.models.signals import Signal

# изменение контрольной суммы файла
checksum_update = Signal()

# создание / перезапись (recut) файла вариации изображения
variation_created = Signal()

# присоединение файла к ресурсу
pre_attach_file = Signal()
post_attach_file = Signal()

# переименование файла
pre_rename_file = Signal()
post_rename_file = Signal()

# удаление файла
pre_delete_file = Signal()
post_delete_file = Signal()

# изменен порядок элементов коллекции
collection_reordered = Signal()



# Generated by Django 3.2.19 on 2023-05-06 03:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('paper_uploads', '0010_auto_20220525_0459'),
    ]

    operations = [
        migrations.AlterField(
            model_name='collection',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='collectionitembase',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='uploadedfile',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='uploadedimage',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
        migrations.AlterField(
            model_name='uploadedsvgfile',
            name='id',
            field=models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID'),
        ),
    ]



# Generated by Django 4.2.5 on 2023-10-07 14:35

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('paper_uploads', '0011_auto_20230506_0349'),
    ]

    operations = [
        migrations.AddField(
            model_name='fileitem',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='imageitem',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='svgitem',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='uploadedfile',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='uploadedimage',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='uploadedsvgfile',
            name='mimetype',
            field=models.CharField(default='', editable=False, max_length=128, verbose_name='MIME Type'),
            preserve_default=False,
        ),
    ]
